Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(114)

Unified Diff: third_party/WebKit/public/web/WebDocument.h

Issue 1773813007: blink: Rename modules/ method to prefix with get when they collide. (Closed) Base URL: https://chromium.googlesource.com/chromium/src.git@master
Patch Set: clash-modules: rebase-fixes Created 4 years, 9 months ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
« no previous file with comments | « third_party/WebKit/public/platform/WebMediaPlayer.h ('k') | third_party/WebKit/public/web/WebFrame.h » ('j') | no next file with comments »
Expand Comments ('e') | Collapse Comments ('c') | Show Comments Hide Comments ('s')
Index: third_party/WebKit/public/web/WebDocument.h
diff --git a/third_party/WebKit/public/web/WebDocument.h b/third_party/WebKit/public/web/WebDocument.h
index 2960c6d905b1756e65e2bf3a5e64f2c84d4c2c79..3db06b6a730f073140b01c3e14a6ffb799ab2f59 100644
--- a/third_party/WebKit/public/web/WebDocument.h
+++ b/third_party/WebKit/public/web/WebDocument.h
@@ -74,8 +74,8 @@ public:
void assign(const WebDocument& e) { WebNode::assign(e); }
BLINK_EXPORT WebURL url() const;
- // Note: Security checks should use the securityOrigin(), not url().
- BLINK_EXPORT WebSecurityOrigin securityOrigin() const;
+ // Note: Security checks should use the getSecurityOrigin(), not url().
+ BLINK_EXPORT WebSecurityOrigin getSecurityOrigin() const;
BLINK_EXPORT bool isSecureContext(WebString& errorMessage) const;
BLINK_EXPORT WebString encoding() const;
« no previous file with comments | « third_party/WebKit/public/platform/WebMediaPlayer.h ('k') | third_party/WebKit/public/web/WebFrame.h » ('j') | no next file with comments »

Powered by Google App Engine
This is Rietveld 408576698